import 'package:equatable/equatable.dart';

import 'event.dart';
import 'timezone.dart';

/// Parsed calendar generated by [parseCalendar]
class ParsedCalendar extends Equatable {
  final String version;
  final String prodID;
  final String calscale;

  /// Timezone standard and daylight
  final Timezone timezone;

  final List<Event> events;

  const ParsedCalendar({
    this.version,
    this.prodID,
    this.calscale,
    this.timezone,
    this.events,
  });

  @override
  List<Object> get props => [
        this.version,
        this.prodID,
        this.calscale,
        this.timezone,
        this.events,
      ];
}

extension ParsedCalendarUtils on ParsedCalendar {
  Iterable<Event> get sortedByDTStart sync* {
    this.events.sort((Event event1, Event event2) =>
        event1.dtstart.compareTo(event2.dtstart));

    for (final event in this.events) {
      yield event;
    }
  }
}
